#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

"""Language data definitions.

This is an automatically generated file, see scripts/generate-language-data

Do not edit, please adjust language definitions in following repository:
https://github.com/WeblateOrg/language-data
"""
# pylint: disable=line-too-long,too-many-lines


# Known language codes
LANGUAGES = {
    "aa",
    "aar",
    "ab",
    "abk",
    "ace",
    "ach",
    "ada",
    "ady",
    "ae",
    "af",
    "afh",
    "afr",
    "aii",
    "ain",
    "ak",
    "aka",
    "akk",
    "alb",
    "ale",
    "alt",
    "am",
    "amh",
    "an",
    "ang",
    "ang@latin",
    "anp",
    "ar",
    "ar_ar",
    "ar_bh",
    "ar_dz",
    "ar_eg",
    "ar_kw",
    "ar_ly",
    "ar_ma",
    "ar_sa",
    "ar_xb",
    "ar_ye",
    "ara",
    "arc",
    "arg",
    "arm",
    "arn",
    "arp",
    "ars",
    "arw",
    "ary",
    "as",
    "asa",
    "asm",
    "ast",
    "av",
    "ava",
    "ave",
    "awa",
    "ay",
    "ayc",
    "aym",
    "az",
    "az_ir",
    "azb",
    "aze",
    "ba",
    "ba_ck",
    "bak",
    "bal",
    "bam",
    "ban",
    "baq",
    "bar",
    "bas",
    "base",
    "bd",
    "be",
    "be@latin",
    "be_latn",
    "be_rby",
    "bej",
    "bel",
    "bem",
    "ben",
    "ber",
    "bez",
    "bg",
    "bgr",
    "bh",
    "bho",
    "bi",
    "bih",
    "bik",
    "bin",
    "bis",
    "bla",
    "bm",
    "bn",
    "bn_bd",
    "bn_in",
    "bnt",
    "bo",
    "bo_cn",
    "bod",
    "bos",
    "br",
    "bra",
    "braz_por",
    "bre",
    "brx",
    "bs",
    "bs_cyrl",
    "bs_latn",
    "bs_latn_ba",
    "bua",
    "bug",
    "bul",
    "bur",
    "by",
    "byn",
    "ca",
    "ca@valencia",
    "ca_ad",
    "ca_es@valencia",
    "ca_ps",
    "ca_valencia",
    "ca_xv",
    "cad",
    "cak",
    "car",
    "cat",
    "ce",
    "ceb",
    "ces",
    "cgg",
    "ch",
    "cha",
    "chb",
    "che",
    "chg",
    "chi",
    "chinese",
    "chinese_chs",
    "chinese_zh",
    "chk",
    "chm",
    "chn",
    "cho",
    "chp",
    "chr",
    "chs",
    "cht",
    "chu",
    "chv",
    "chy",
    "ckb",
    "ckb_iq",
    "ckb_ir",
    "cmn",
    "cn",
    "co",
    "cop",
    "cor",
    "cos",
    "cpe",
    "cpf",
    "cpp",
    "cr",
    "cre",
    "crh",
    "crp",
    "cs",
    "csb",
    "csy",
    "cu",
    "cv",
    "cy",
    "cym",
    "cz",
    "cze",
    "da",
    "dak",
    "dan",
    "dar",
    "de",
    "de@formal",
    "de@informal",
    "de_1901",
    "de_at",
    "de_ch",
    "de_de_x_formal",
    "de_de_x_informal",
    "de_fo",
    "de_form",
    "de_lu",
    "del",
    "den",
    "des",
    "deu",
    "dgo",
    "dgr",
    "din",
    "div",
    "dk",
    "doi",
    "dsb",
    "dua",
    "dum",
    "dut",
    "dutch_be",
    "dv",
    "dyu",
    "dz",
    "dzo",
    "ee",
    "efi",
    "eg",
    "egy",
    "eka",
    "el",
    "ell",
    "elx",
    "en",
    "en_au",
    "en_ca",
    "en_devel",
    "en_en",
    "en_gb",
    "en_ie",
    "en_in",
    "en_nz",
    "en_ph",
    "en_us",
    "en_xa",
    "en_za",
    "ena",
    "eng",
    "english_uk",
    "enm",
    "enp",
    "enu",
    "eo",
    "epo",
    "es",
    "es_419",
    "es_ar",
    "es_bo",
    "es_cl",
    "es_co",
    "es_cr",
    "es_do",
    "es_ec",
    "es_eu",
    "es_mx",
    "es_ni",
    "es_pa",
    "es_pe",
    "es_pr",
    "es_sv",
    "es_us",
    "es_uy",
    "es_ve",
    "esp",
    "est",
    "et",
    "eu",
    "eus",
    "ewe",
    "ewo",
    "ext",
    "fa",
    "fa_af",
    "fan",
    "fao",
    "fas",
    "fat",
    "ff",
    "fi",
    "fij",
    "fil",
    "fin",
    "fj",
    "flemish",
    "fo",
    "fon",
    "fr",
    "fr@formal",
    "fr@informal",
    "fr_ag",
    "fr_be",
    "fr_ca",
    "fr_ch",
    "fr_fo",
    "fr_form",
    "fr_fr_x_formal",
    "fr_fr_x_informal",
    "fr_lu",
    "fr_sn",
    "fra",
    "frb",
    "frc",
    "fre",
    "frm",
    "fro",
    "frp",
    "frr",
    "frs",
    "fry",
    "ful",
    "fur",
    "fy",
    "ga",
    "gaa",
    "gae",
    "gay",
    "gba",
    "gbm",
    "gd",
    "geo",
    "ger",
    "gez",
    "gil",
    "gl",
    "gla",
    "gle",
    "glg",
    "glk",
    "glv",
    "gmh",
    "gn",
    "goh",
    "gon",
    "gor",
    "got",
    "gr",
    "grb",
    "grc",
    "gre",
    "grn",
    "gsw",
    "gu",
    "gu_in",
    "gug",
    "guj",
    "gun",
    "guw",
    "gv",
    "gwi",
    "ha",
    "hai",
    "hat",
    "hau",
    "haw",
    "hbs",
    "he",
    "he_il",
    "heb",
    "her",
    "hi",
    "hi_latn",
    "hil",
    "hin",
    "hit",
    "hmn",
    "hmo",
    "hne",
    "ho",
    "hr",
    "hrv",
    "hrx",
    "hsb",
    "ht",
    "hu",
    "hun",
    "hup",
    "hus",
    "hy",
    "hye",
    "hz",
    "ia",
    "iba",
    "ibo",
    "ice",
    "id",
    "ido",
    "ie",
    "ig",
    "ii",
    "iii",
    "ik",
    "iku",
    "ile",
    "ilo",
    "in",
    "in_id",
    "ina",
    "ind",
    "inh",
    "io",
    "ipk",
    "is",
    "isl",
    "it",
    "it_ch",
    "ita",
    "its",
    "iu",
    "iw",
    "iw_il",
    "ja",
    "ja_ja",
    "ja_ks",
    "jam",
    "jav",
    "jbo",
    "jgo",
    "ji",
    "jmc",
    "jp",
    "jpn",
    "jpr",
    "jrb",
    "jv",
    "jw",
    "ka",
    "kaa",
    "kab",
    "kac",
    "kaj",
    "kal",
    "kam",
    "kan",
    "kas",
    "kat",
    "kau",
    "kaw",
    "kaz",
    "kbd",
    "kcg",
    "kde",
    "kea",
    "kg",
    "kha",
    "khm",
    "kho",
    "ki",
    "kik",
    "kin",
    "kir",
    "kj",
    "kk",
    "kk@latin",
    "kk_cyrl",
    "kk_latn",
    "kkj",
    "kl",
    "km",
    "kmb",
    "kmr",
    "kmr_latn",
    "kn",
    "ko",
    "ko_ko",
    "kok",
    "kom",
    "kon",
    "kor",
    "kos",
    "kpe",
    "kr",
    "krc",
    "krl",
    "kru",
    "ks",
    "ksb",
    "ksh",
    "ku",
    "ku_iq",
    "kua",
    "kum",
    "kur",
    "kut",
    "kv",
    "kw",
    "ky",
    "kz",
    "la",
    "lad",
    "lag",
    "lah",
    "lam",
    "lao",
    "lat",
    "lav",
    "lb",
    "lez",
    "lg",
    "li",
    "lim",
    "lin",
    "lit",
    "lk",
    "lki",
    "lkt",
    "ln",
    "lo",
    "lol",
    "loz",
    "lt",
    "ltg",
    "ltz",
    "lu",
    "lua",
    "lub",
    "lug",
    "lui",
    "lun",
    "luo",
    "lus",
    "lv",
    "mac",
    "mad",
    "mag",
    "mah",
    "mai",
    "mak",
    "mal",
    "man",
    "mao",
    "mar",
    "mas",
    "may",
    "mdf",
    "mdr",
    "me",
    "men",
    "mfe",
    "mg",
    "mga",
    "mgo",
    "mh",
    "mhr",
    "mi",
    "mia",
    "mic",
    "min",
    "mjw",
    "mk",
    "mkd",
    "ml",
    "mlg",
    "mlt",
    "mn",
    "mnc",
    "mni",
    "mnk",
    "mnw",
    "mo",
    "moh",
    "mon",
    "mos",
    "mr",
    "mri",
    "ms",
    "ms_arab",
    "msa",
    "mt",
    "mus",
    "mwl",
    "mwr",
    "my",
    "mya",
    "myv",
    "na",
    "nah",
    "nan",
    "nap",
    "naq",
    "nau",
    "nav",
    "nb",
    "nb_no",
    "nbl",
    "nd",
    "nde",
    "ndo",
    "nds",
    "ne",
    "nep",
    "new",
    "ng",
    "nia",
    "niu",
    "nl",
    "nl_be",
    "nlb",
    "nld",
    "nn",
    "nnh",
    "nno",
    "no",
    "no_nb",
    "no_no",
    "nob",
    "nog",
    "non",
    "nor",
    "norwegian",
    "np",
    "nqo",
    "nr",
    "nso",
    "nv",
    "nwc",
    "ny",
    "nya",
    "nym",
    "nyn",
    "nyo",
    "nzi",
    "oc",
    "oci",
    "oj",
    "oji",
    "om",
    "or",
    "ori",
    "orm",
    "os",
    "osa",
    "oss",
    "ota",
    "otk",
    "pa",
    "pa_pk",
    "pag",
    "pal",
    "pam",
    "pan",
    "pap",
    "pau",
    "peo",
    "per",
    "phn",
    "pi",
    "pk",
    "pl",
    "pli",
    "plk",
    "pms",
    "pol",
    "pon",
    "por",
    "portuguese_br",
    "portuguese_portugal",
    "pr",
    "prg",
    "pro",
    "ps",
    "pt",
    "pt_ao",
    "pt_br",
    "pt_pt",
    "ptb",
    "ptg",
    "pu",
    "pus",
    "qu",
    "qu_ec",
    "quc",
    "que",
    "raj",
    "rap",
    "rar",
    "rcf",
    "rm",
    "rn",
    "ro",
    "ro_md",
    "rof",
    "roh",
    "rom",
    "ron",
    "rs",
    "ru",
    "ru_r",
    "ru_rr",
    "ru_ua",
    "rue",
    "rum",
    "run",
    "rup",
    "rus",
    "rw",
    "rwk",
    "sa",
    "sad",
    "sag",
    "sah",
    "sai",
    "sam",
    "san",
    "saq",
    "sas",
    "sat",
    "sc",
    "scc",
    "schinese",
    "scn",
    "sco",
    "scr",
    "sd",
    "sdh",
    "se",
    "seh",
    "sel",
    "serbo_croatian",
    "ses",
    "sg",
    "sga",
    "sgn",
    "sh",
    "shi",
    "shn",
    "si",
    "sid",
    "sin",
    "sk",
    "sky",
    "sl",
    "sl_sl",
    "slk",
    "slo",
    "slv",
    "sm",
    "sma",
    "sme",
    "smi",
    "smj",
    "sml",
    "smn",
    "smo",
    "sms",
    "sn",
    "sna",
    "snd",
    "snk",
    "so",
    "sog",
    "som",
    "son",
    "sot",
    "source",
    "spa",
    "sq",
    "sqi",
    "sr",
    "sr@cyrillic",
    "sr@ije",
    "sr@ijekavian",
    "sr@ijekavian_latn",
    "sr@ijekavianlatin",
    "sr@latin",
    "sr_cs",
    "sr_cyrl",
    "sr_cyrl_rs",
    "sr_latn",
    "sr_latn_rs",
    "sr_me",
    "sr_rs@cyrillic",
    "sr_rs@latin",
    "srb",
    "srd",
    "srl",
    "srn",
    "srp",
    "srr",
    "ss",
    "ssw",
    "ssy",
    "st",
    "su",
    "suk",
    "sun",
    "sus",
    "sux",
    "sv",
    "sve",
    "svk",
    "sw",
    "sw_cd",
    "sw_tz",
    "swa",
    "swe",
    "syc",
    "syr",
    "szl",
    "ta",
    "ta_lk",
    "tah",
    "tam",
    "tat",
    "tchinese",
    "te",
    "tel",
    "tem",
    "teo",
    "ter",
    "tet",
    "tg",
    "tgk",
    "tgl",
    "th",
    "tha",
    "ti",
    "tib",
    "tig",
    "tir",
    "tiv",
    "tk",
    "tkl",
    "tl",
    "tlh",
    "tlh-qaak",
    "tli",
    "tmh",
    "tn",
    "to",
    "tog",
    "ton",
    "tpi",
    "tr",
    "trk",
    "trv",
    "ts",
    "tsi",
    "tsj",
    "tsn",
    "tso",
    "tt",
    "tt@iqtelif",
    "tuk",
    "tum",
    "tur",
    "tvl",
    "tw",
    "twi",
    "ty",
    "tyv",
    "tzj",
    "tzm",
    "ua",
    "udm",
    "ug",
    "uga",
    "uig",
    "uk",
    "ukr",
    "umb",
    "und",
    "ur",
    "ur_in",
    "ur_pk",
    "urd",
    "us",
    "uz",
    "uz@cyrillic",
    "uz@latin",
    "uz@latn",
    "uz_latn",
    "uzb",
    "vai",
    "val_es",
    "ve",
    "vec",
    "ven",
    "vi",
    "vie",
    "vls",
    "vn",
    "vo",
    "vol",
    "vot",
    "vun",
    "wa",
    "wae",
    "wal",
    "war",
    "was",
    "wel",
    "wen",
    "wln",
    "wo",
    "wol",
    "xal",
    "xbelorussian",
    "xh",
    "xho",
    "xog",
    "yao",
    "yap",
    "yi",
    "yid",
    "yo",
    "yor",
    "yue",
    "za",
    "zap",
    "zbl",
    "zen",
    "zgh",
    "zh",
    "zh_chs",
    "zh_cmn_hans",
    "zh_cmn_hant",
    "zh_cn",
    "zh_hans",
    "zh_hans_cn",
    "zh_hans_sg",
    "zh_hant",
    "zh_hant@zh",
    "zh_hant_hk",
    "zh_hant_tw",
    "zh_hk",
    "zh_latn",
    "zh_latn@pinyin",
    "zh_latn_pinyin",
    "zh_sg",
    "zh_tw",
    "zha",
    "zhcn",
    "zho",
    "zhtw",
    "zu",
    "zul",
    "zun",
    "zza",
}
